@@ -25,10 +25,10 @@ from airflow.providers.common.sql.hooks.sql import DbApiHook
 class VerticaHook(DbApiHook):
     """Interact with Vertica."""
 
-    conn_name_attr = 'vertica_conn_id'
-    default_conn_name = 'vertica_default'
-    conn_type = 'vertica'
-    hook_name = 'Vertica'
+    conn_name_attr = "vertica_conn_id"
+    default_conn_name = "vertica_default"
+    conn_type = "vertica"
+    hook_name = "Vertica"
     supports_autocommit = True
 
     def get_conn(self) -> connect:
@@ -36,9 +36,9 @@ class VerticaHook(DbApiHook):
         conn = self.get_connection(self.vertica_conn_id)  # type: ignore
         conn_config = {
             "user": conn.login,
-            "password": conn.password or '',
+            "password": conn.password or "",
             "database": conn.schema,
-            "host": conn.host or 'localhost',
+            "host": conn.host or "localhost",
         }
 
         if not conn.port:
